@@ -5,6 +5,7 @@ import (
 	"bytes"
 	"crypto/aes"
 	"encoding/base64"
+	"path/filepath"
 	"syscall"
 
 	"github.com/rfjakob/eme"
@@ -35,6 +36,8 @@ type NameTransform struct {
 	// B64 = either base64.URLEncoding or base64.RawURLEncoding, depending
 	// on the Raw64 feature flag
 	B64 *base64.Encoding
+	// Patterns to bypass decryption
+	BadnamePatterns []string
 }
 
 // New returns a new NameTransform instance.
@@ -50,9 +53,24 @@ func New(e *eme.EMECipher, longNames bool, raw64 bool) *NameTransform {
 	}
 }
 
-// DecryptName decrypts a base64-encoded encrypted filename "cipherName" using the
-// initialization vector "iv".
+// DecryptName calls decryptName to try and decrypt a base64-encoded encrypted
+// filename "cipherName", and failing that checks if it can be bypassed
 func (n *NameTransform) DecryptName(cipherName string, iv []byte) (string, error) {
+	res, err := n.decryptName(cipherName, iv)
+	if err != nil {
+		for _, pattern := range n.BadnamePatterns {
+			match, err := filepath.Match(pattern, cipherName)
+			if err == nil && match { // Pattern should have been validated already
+				return "GOCRYPTFS_BAD_NAME " + cipherName, nil
+			}
+		}
+	}
+	return res, err
+}
+
+// decryptName decrypts a base64-encoded encrypted filename "cipherName" using the
+// initialization vector "iv".
+func (n *NameTransform) decryptName(cipherName string, iv []byte) (string, error) {
 	bin, err := n.B64.DecodeString(cipherName)
 	if err != nil {
 		return "", err
@@ -87,8 +105,8 @@ func (n *NameTransform) DecryptName(cipherName string, iv []byte) (string, error
 	return plain, err
 }
 
-// EncryptName encrypts "plainName", returns a base64-encoded "cipherName64".
-// The encryption is either CBC or EME, depending on "useEME".
+// EncryptName encrypts "plainName", returns a base64-encoded "cipherName64",
+// encrypted using EME (https://github.com/rfjakob/eme).
 //
 // This function is exported because in some cases, fusefrontend needs access
 // to the full (not hashed) name if longname is used.
