@@ -12,7 +12,11 @@ func TestOpenNofollow(t *testing.T) {
 		t.Fatal(err)
 	}
 	// Create a file
-	fd, err := OpenNofollow(tmpDir, "d1/d2/d3/f1", syscall.O_RDWR|syscall.O_CREAT|syscall.O_EXCL, 0600)
+	dirfd, err := OpenDirNofollow(tmpDir, "d1/d2/d3")
+	if err != nil {
+		t.Fatal(err)
+	}
+	fd, err := Openat(dirfd, "f1", syscall.O_RDWR|syscall.O_CREAT|syscall.O_EXCL, 0600)
 	if err != nil {
 		t.Fatal(err)
 	}
@@ -27,7 +31,7 @@ func TestOpenNofollow(t *testing.T) {
 		t.Fatal(err)
 	}
 	os.Symlink(tmpDir+"/d1.renamed", tmpDir+"/d1")
-	fd, err = OpenNofollow(tmpDir, "d1/d2/d3/f1", syscall.O_RDWR|syscall.O_CREAT, 0600)
+	fd, err = OpenDirNofollow(tmpDir, "d1/d2/d3")
 	if err == nil {
 		t.Fatalf("should have failed")
 	}
@@ -35,7 +39,7 @@ func TestOpenNofollow(t *testing.T) {
 		t.Errorf("expected ELOOP or ENOTDIR, got %v", err)
 	}
 	// Check to see that the base dir can be opened as well
-	fd, err = OpenNofollow(tmpDir, "", syscall.O_RDONLY, 0)
+	fd, err = OpenDirNofollow(tmpDir, "")
 	if err != nil {
 		t.Errorf("cannot open base dir: %v", err)
 	} else {
