@@ -1,6 +1,7 @@
 package main
 
 import (
+	"bytes"
 	"encoding/json"
 	"fmt"
 	"log"
@@ -285,6 +286,17 @@ func initFuseFrontend(args *argContainer) (pfs pathfs.FileSystem, wipeKeys func(
 	cCore := cryptocore.New(masterkey, cryptoBackend, contentenc.DefaultIVBits, args.hkdf, args.forcedecode)
 	cEnc := contentenc.New(cCore, contentenc.DefaultBS, args.forcedecode)
 	nameTransform := nametransform.New(cCore.EMECipher, frontendArgs.LongNames, args.raw64)
+	// Init badname patterns
+	nameTransform.BadnamePatterns = make([]string, 0)
+	for _, pattern := range args.badname {
+		_, err := filepath.Match(pattern, "") // Make sure pattern is valid
+		if err != nil {
+			tlog.Fatal.Printf("-badname: invalid pattern %q supplied", pattern)
+			os.Exit(exitcodes.Usage)
+		} else {
+			nameTransform.BadnamePatterns = append(nameTransform.BadnamePatterns, pattern)
+		}
+	}
 	// After the crypto backend is initialized,
 	// we can purge the master key from memory.
 	for i := range masterkey {
@@ -362,7 +374,9 @@ func initGoFuse(fs pathfs.FileSystem, args *argContainer) *fuse.Server {
 		tlog.Info.Printf(tlog.ColorYellow + "THE OPTION \"-forcedecode\" IS ACTIVE. GOCRYPTFS WILL RETURN CORRUPT DATA!" +
 			tlog.ColorReset)
 	}
-	if args.nonempty {
+	// fusermount from libfuse 3.x removed the "nonempty" option and exits
+	// with an error if it sees it. Only add it to the options on libfuse 2.x.
+	if args.nonempty && haveFusermount2() {
 		mOpts.Options = append(mOpts.Options, "nonempty")
 	}
 	// Set values shown in "df -T" and friends
@@ -436,6 +450,29 @@ func initGoFuse(fs pathfs.FileSystem, args *argContainer) *fuse.Server {
 	return srv
 }
 
+// haveFusermount2 finds out if the "fusermount" binary is from libfuse 2.x.
+func haveFusermount2() bool {
+	path, err := exec.LookPath("fusermount")
+	if err != nil {
+		path = "/bin/fusermount"
+	}
+	cmd := exec.Command(path, "-V")
+	var out bytes.Buffer
+	cmd.Stdout = &out
+	err = cmd.Run()
+	if err != nil {
+		tlog.Warn.Printf("warning: haveFusermount2: %v", err)
+		return false
+	}
+	// libfuse 2: fusermount version: 2.9.9
+	// libfuse 3: fusermount3 version: 3.9.0
+	v := out.String()
+	if strings.HasPrefix(v, "fusermount version") {
+		return true
+	}
+	return false
+}
+
 func handleSigint(srv *fuse.Server, mountpoint string) {
 	ch := make(chan os.Signal, 1)
 	signal.Notify(ch, os.Interrupt)
