@@ -47,7 +47,7 @@ func Test1980Tar(t *testing.T) {
 // The sequence below caused an I/O error to be returned.
 func TestOpenTruncateRead(t *testing.T) {
 	fn := test_helpers.DefaultPlainDir + "/TestTruncateWrite"
-	// First FD is used for write and trucate.
+	// First FD is used for write and truncate.
 	writeFd, err := os.Create(fn)
 	if err != nil {
 		t.Fatal(err)
@@ -232,6 +232,9 @@ func TestMvWarningSymlink(t *testing.T) {
 	out, err := cmd.CombinedOutput()
 	if err != nil {
 		t.Log(string(out))
+		if runtime.GOOS == "darwin" {
+			t.Skip("mv on darwin chokes on broken symlinks, see https://github.com/rfjakob/gocryptfs/issues/349")
+		}
 		t.Fatal(err)
 	}
 	if len(out) != 0 {
